/* --8<--8<--8<--8<--
 *
 * Copyright (C) 2006 Smithsonian Astrophysical Observatory
 *
 * This file is part of mst_rdb
 *
 * mst_rdb is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * mst_rdb is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the 
 *       Free Software Foundation, Inc. 
 *       51 Franklin Street, Fifth Floor
 *       Boston, MA  02110-1301, USA
 *
 * -->8-->8-->8-->8-- */

/* rdb_count.c */

#include "mst_rdb.h"

#include <stdlib.h>
#include <stdio.h>

#include <tracefct/tracefct.h>
#include <tracefct/exiterrvals.h>
#include <suplib/io.h>

/* hack for non-posix-ness of SunOS4 */
#ifndef SEEK_SET
#define SEEK_SET 0
#endif
/*

  PROCEDURE
    rdb_count - Grab columns of data from an rdb data file.

  DESCRIPTION
    rdb_count counts the lines in an /rdb-format table file
    which has previously been opened, had its header read, and
    had columns mapped (using functions elsewhere in this library).
    On exit, the file is left ready to read the first data element.

  RETURNS
    The routine returns the number of data records in the file.  If the
    file cannot be rewound, it returns -1.

  AUTHOR
    Diab Jerius

*/
long
rdb_count(
  FILE *fin,			/* the stream to parse */
  rdbHeader *hdr		/* the rdb file description */
)
{
  char *buf;
  long int count;

  /* if can't rewind, can't count, either! */
  if ( ! hdr->can_rewind )
    return -1;

  /* count lines */
  count = 0;
  while ( (buf = fget_rec(fin, hdr->buf)) )
  {
    if(buf[0])  /* ignore empty lines */
      count++;
  }
  
  /* done; rewind the file to point at first data element */
  switch ( rdb_rewind( fin, hdr ) )
  {
  case 0:
    break;

  case 1:
    count = -1;
    break;

  default:
    tf_enter( "rdb_count");
    tf_exit(ExitERR_misc,"error rewinding file");
  }

  return count;
}
